summaryrefslogtreecommitdiffstats
path: root/chrome/browser/chromeos
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-10 22:33:23 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-10 22:33:23 +0000
commit0f42477a45fb4fb6714a9c872f9ed37639c62852 (patch)
tree5c140d84db0fde643c88449a34b26ac4c5539027 /chrome/browser/chromeos
parent133bf5be612e082d10a96e995c61827613a0d3d3 (diff)
downloadchromium_src-0f42477a45fb4fb6714a9c872f9ed37639c62852.zip
chromium_src-0f42477a45fb4fb6714a9c872f9ed37639c62852.tar.gz
chromium_src-0f42477a45fb4fb6714a9c872f9ed37639c62852.tar.bz2
WebUI: Get rid of more referecens to DOMUI. Part 2.
BUG= 59945 TEST=trybots Review URL: http://codereview.chromium.org/6469021 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@74512 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/chromeos')
-rw-r--r--chrome/browser/chromeos/dom_ui/imageburner_ui.cc8
-rw-r--r--chrome/browser/chromeos/dom_ui/login/login_ui.cc8
-rw-r--r--chrome/browser/chromeos/dom_ui/menu_ui.cc14
-rw-r--r--chrome/browser/chromeos/dom_ui/mobile_setup_ui.cc14
-rw-r--r--chrome/browser/chromeos/dom_ui/register_page_ui.cc12
-rw-r--r--chrome/browser/chromeos/dom_ui/system_info_ui.cc10
6 files changed, 33 insertions, 33 deletions
diff --git a/chrome/browser/chromeos/dom_ui/imageburner_ui.cc b/chrome/browser/chromeos/dom_ui/imageburner_ui.cc
index 8aaa576..f988dd5 100644
--- a/chrome/browser/chromeos/dom_ui/imageburner_ui.cc
+++ b/chrome/browser/chromeos/dom_ui/imageburner_ui.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -201,8 +201,8 @@ ImageBurnHandler::~ImageBurnHandler() {
download_manager_->RemoveObserver(this);
}
-WebUIMessageHandler* ImageBurnHandler::Attach(DOMUI* dom_ui) {
- return WebUIMessageHandler::Attach(dom_ui);
+WebUIMessageHandler* ImageBurnHandler::Attach(WebUI* web_ui) {
+ return WebUIMessageHandler::Attach(web_ui);
}
void ImageBurnHandler::RegisterMessages() {
@@ -645,7 +645,7 @@ net::FileStream* ImageBurnResourceManager::CreateFileStream(
// ImageBurnUI
//
////////////////////////////////////////////////////////////////////////////////
-ImageBurnUI::ImageBurnUI(TabContents* contents) : DOMUI(contents) {
+ImageBurnUI::ImageBurnUI(TabContents* contents) : WebUI(contents) {
ImageBurnHandler* handler = new ImageBurnHandler(contents);
AddMessageHandler((handler)->Attach(this));
ImageBurnUIHTMLSource* html_source = new ImageBurnUIHTMLSource();
diff --git a/chrome/browser/chromeos/dom_ui/login/login_ui.cc b/chrome/browser/chromeos/dom_ui/login/login_ui.cc
index a1ba4e0..9cc6b5a 100644
--- a/chrome/browser/chromeos/dom_ui/login/login_ui.cc
+++ b/chrome/browser/chromeos/dom_ui/login/login_ui.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -61,8 +61,8 @@ LoginUIHandler::LoginUIHandler()
facade_->Setup();
}
-WebUIMessageHandler* LoginUIHandler::Attach(DOMUI* dom_ui) {
- return WebUIMessageHandler::Attach(dom_ui);
+WebUIMessageHandler* LoginUIHandler::Attach(WebUI* web_ui) {
+ return WebUIMessageHandler::Attach(web_ui);
}
void LoginUIHandler::RegisterMessages() {
@@ -151,7 +151,7 @@ void LoginUIHandler::OnOffTheRecordLoginSuccess() {
//
////////////////////////////////////////////////////////////////////////////////
LoginUI::LoginUI(TabContents* contents)
- : DOMUI(contents) {
+ : WebUI(contents) {
LoginUIHandler* handler = new LoginUIHandler();
AddMessageHandler(handler->Attach(this));
LoginUIHTMLSource* html_source =
diff --git a/chrome/browser/chromeos/dom_ui/system_info_ui.cc b/chrome/browser/chromeos/dom_ui/system_info_ui.cc
index 93b8456..3d485eb 100644
--- a/chrome/browser/chromeos/dom_ui/system_info_ui.cc
+++ b/chrome/browser/chromeos/dom_ui/system_info_ui.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -68,7 +68,7 @@ class SystemInfoHandler : public WebUIMessageHandler,
virtual ~SystemInfoHandler();
// WebUIMessageHandler implementation.
- virtual WebUIMessageHandler* Attach(DOMUI* dom_ui);
+ virtual WebUIMessageHandler* Attach(WebUI* web_ui);
virtual void RegisterMessages();
private:
@@ -160,9 +160,9 @@ SystemInfoHandler::SystemInfoHandler() {
SystemInfoHandler::~SystemInfoHandler() {
}
-WebUIMessageHandler* SystemInfoHandler::Attach(DOMUI* dom_ui) {
+WebUIMessageHandler* SystemInfoHandler::Attach(WebUI* web_ui) {
// TODO(stevenjb): customize handler attach if needed...
- return WebUIMessageHandler::Attach(dom_ui);
+ return WebUIMessageHandler::Attach(web_ui);
}
void SystemInfoHandler::RegisterMessages() {
@@ -175,7 +175,7 @@ void SystemInfoHandler::RegisterMessages() {
//
////////////////////////////////////////////////////////////////////////////////
-SystemInfoUI::SystemInfoUI(TabContents* contents) : DOMUI(contents) {
+SystemInfoUI::SystemInfoUI(TabContents* contents) : WebUI(contents) {
SystemInfoHandler* handler = new SystemInfoHandler();
AddMessageHandler((handler)->Attach(this));
SystemInfoUIHTMLSource* html_source = new SystemInfoUIHTMLSource();
diff --git a/chrome/browser/chromeos/dom_ui/menu_ui.cc b/chrome/browser/chromeos/dom_ui/menu_ui.cc
index f0e3b48..dc3b0c9 100644
--- a/chrome/browser/chromeos/dom_ui/menu_ui.cc
+++ b/chrome/browser/chromeos/dom_ui/menu_ui.cc
@@ -248,7 +248,7 @@ class MenuHandler : public chromeos::MenuHandlerBase,
virtual ~MenuHandler();
// WebUIMessageHandler implementation.
- virtual WebUIMessageHandler* Attach(DOMUI* dom_ui);
+ virtual WebUIMessageHandler* Attach(WebUI* web_ui);
virtual void RegisterMessages();
private:
@@ -259,7 +259,7 @@ class MenuHandler : public chromeos::MenuHandlerBase,
void HandleMoveInputToParent(const ListValue* values);
void HandleCloseAll(const ListValue* values);
void HandleModelUpdated(const ListValue* values);
// This is a utility DOMUI message to print debug message.
// Menu can't use dev tool as it lives outside of browser.
// TODO(oshima): This is inconvenient and figure out how we can use
// dev tools for menus (and other domui that does not belong to browser).
@@ -350,9 +350,9 @@ MenuHandler::MenuHandler() : loaded_(false) {
MenuHandler::~MenuHandler() {
}
-WebUIMessageHandler* MenuHandler::Attach(DOMUI* dom_ui) {
- WebUIMessageHandler* handler = WebUIMessageHandler::Attach(dom_ui);
- dom_ui->tab_contents()->set_delegate(this);
+WebUIMessageHandler* MenuHandler::Attach(WebUI* web_ui) {
+ WebUIMessageHandler* handler = WebUIMessageHandler::Attach(web_ui);
+ web_ui->tab_contents()->set_delegate(this);
return handler;
}
@@ -528,7 +528,7 @@ ui::MenuModel* MenuHandlerBase::GetMenuModel() {
//
////////////////////////////////////////////////////////////////////////////////
-MenuUI::MenuUI(TabContents* contents) : DOMUI(contents) {
+MenuUI::MenuUI(TabContents* contents) : WebUI(contents) {
MenuHandler* handler = new MenuHandler();
AddMessageHandler((handler)->Attach(this));
@@ -537,7 +537,7 @@ MenuUI::MenuUI(TabContents* contents) : DOMUI(contents) {
}
MenuUI::MenuUI(TabContents* contents, ChromeURLDataManager::DataSource* source)
- : DOMUI(contents) {
+ : WebUI(contents) {
MenuHandler* handler = new MenuHandler();
AddMessageHandler((handler)->Attach(this));
@@ -259,7 +259,7 @@ class MenuHandler : public chromeos::MenuHandlerBase,
void HandleCloseAll(const ListValue* values);
void HandleModelUpdated(const ListValue* values);
- // This is a utility DOMUI message to print debug message.
+ // This is a utility WebUI message to print debug message.
// Menu can't use dev tool as it lives outside of browser.
// TODO(oshima): This is inconvenient and figure out how we can use
diff --git a/chrome/browser/chromeos/dom_ui/mobile_setup_ui.cc b/chrome/browser/chromeos/dom_ui/mobile_setup_ui.cc
index ac3688e..5d422e9 100644
--- a/chrome/browser/chromeos/dom_ui/mobile_setup_ui.cc
+++ b/chrome/browser/chromeos/dom_ui/mobile_setup_ui.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2006-2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -164,7 +164,7 @@ class MobileSetupHandler
void Init(TabContents* contents);
// WebUIMessageHandler implementation.
- virtual WebUIMessageHandler* Attach(DOMUI* dom_ui);
+ virtual WebUIMessageHandler* Attach(WebUI* web_ui);
virtual void RegisterMessages();
// NetworkLibrary::NetworkManagerObserver implementation.
@@ -222,7 +222,7 @@ class MobileSetupHandler
DISALLOW_COPY_AND_ASSIGN(TaskProxy);
};
// Handlers for JS DOMUI messages.
void HandleSetTransactionStatus(const ListValue* args);
void HandleStartActivation(const ListValue* args);
void SetTransactionStatus(const std::string& status);
@@ -260,7 +260,7 @@ class MobileSetupHandler
// Check the current cellular network for error conditions.
bool GotActivationError(const chromeos::CellularNetwork* network,
std::string* error);
// Sends status updates to DOMUI page.
void UpdatePage(chromeos::CellularNetwork* network,
const std::string& error_description);
// Changes internal state.
@@ -464,8 +464,8 @@ MobileSetupHandler::~MobileSetupHandler() {
ReEnableOtherConnections();
}
-WebUIMessageHandler* MobileSetupHandler::Attach(DOMUI* dom_ui) {
- return WebUIMessageHandler::Attach(dom_ui);
+WebUIMessageHandler* MobileSetupHandler::Attach(WebUI* web_ui) {
+ return WebUIMessageHandler::Attach(web_ui);
}
void MobileSetupHandler::Init(TabContents* contents) {
@@ -1313,7 +1313,7 @@ void MobileSetupHandler::LoadCellularConfig() {
//
////////////////////////////////////////////////////////////////////////////////
-MobileSetupUI::MobileSetupUI(TabContents* contents) : DOMUI(contents) {
+MobileSetupUI::MobileSetupUI(TabContents* contents) : WebUI(contents) {
const chromeos::CellularNetwork* network = GetCellularNetwork();
std::string service_path = network ? network->service_path() : std::string();
MobileSetupHandler* handler = new MobileSetupHandler(service_path);
@@ -222,7 +222,7 @@ class MobileSetupHandler
DISALLOW_COPY_AND_ASSIGN(TaskProxy);
};
- // Handlers for JS DOMUI messages.
+ // Handlers for JS WebUI messages.
void HandleSetTransactionStatus(const ListValue* args);
void HandleStartActivation(const ListValue* args);
@@ -260,7 +260,7 @@ class MobileSetupHandler
bool GotActivationError(const chromeos::CellularNetwork* network,
std::string* error);
- // Sends status updates to DOMUI page.
+ // Sends status updates to WebUI page.
void UpdatePage(chromeos::CellularNetwork* network,
const std::string& error_description);
diff --git a/chrome/browser/chromeos/dom_ui/register_page_ui.cc b/chrome/browser/chromeos/dom_ui/register_page_ui.cc
index f3e4453..bd61126 100644
--- a/chrome/browser/chromeos/dom_ui/register_page_ui.cc
+++ b/chrome/browser/chromeos/dom_ui/register_page_ui.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -118,11 +118,11 @@ class RegisterPageHandler : public WebUIMessageHandler,
void Init();
// WebUIMessageHandler implementation.
- virtual WebUIMessageHandler* Attach(DOMUI* dom_ui);
+ virtual WebUIMessageHandler* Attach(WebUI* web_ui);
virtual void RegisterMessages();
private:
// Handlers for JS DOMUI messages.
void HandleGetRegistrationUrl(const ListValue* args);
void HandleGetUserInfo(const ListValue* args);
@@ -201,8 +201,8 @@ RegisterPageHandler::RegisterPageHandler() {
RegisterPageHandler::~RegisterPageHandler() {
}
-WebUIMessageHandler* RegisterPageHandler::Attach(DOMUI* dom_ui) {
- return WebUIMessageHandler::Attach(dom_ui);
+WebUIMessageHandler* RegisterPageHandler::Attach(WebUI* web_ui) {
+ return WebUIMessageHandler::Attach(web_ui);
}
void RegisterPageHandler::Init() {
@@ -317,7 +317,7 @@ void RegisterPageHandler::SendUserInfo() {
//
////////////////////////////////////////////////////////////////////////////////
-RegisterPageUI::RegisterPageUI(TabContents* contents) : DOMUI(contents){
+RegisterPageUI::RegisterPageUI(TabContents* contents) : WebUI(contents){
RegisterPageHandler* handler = new RegisterPageHandler();
AddMessageHandler((handler)->Attach(this));
handler->Init();
@@ -118,11 +118,11 @@ class RegisterPageHandler : public WebUIMessageHandler,
virtual void RegisterMessages();
private:
- // Handlers for JS DOMUI messages.
+ // Handlers for JS WebUI messages.
void HandleGetRegistrationUrl(const ListValue* args);
void HandleGetUserInfo(const ListValue* args);